==> guikachu_1.0.1.orig.tar.gz: guikachu-1.0.1/src/form-editor/button-prop.h <==
//$Id: button-prop.h,v 1.7 2001/08/19 15:02:33 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_BUTTON_PROP_H
#define GUIKACHU_FORM_EDITOR_BUTTON_PROP_H

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ButtonProperties;
	}
    }
}

#include "button.h"

#include <sigc++/object.h>
#include <gtk--/optionmenu.h>

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ButtonProperties: public SigC::Object
	    {
		Widgets::Button   *res;
		
		/* Property editor */
		Gtk::Widget       *property_editor;
		
		Gtk::OptionMenu   *frame_combo;
	    public:
		ButtonProperties (Widgets::Button *res);
		~ButtonProperties ();
		Gtk::Widget *get_editor ();

	    private:
		void update ();
		bool update_block;
		
		void frame_menu_cb (Widgets::ButtonFrameType frame_type);
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_BUTTON_PROP_H */

==> guikachu_1.4.0.orig.tar.gz: guikachu-1.4.0/src/form-editor/button-prop.h <==
//$Id: button-prop.h,v 1.11 2003/06/30 14:07:57 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001-2003 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_FORM_EDITOR_BUTTON_PROP_H
#define GUIKACHU_FORM_EDITOR_BUTTON_PROP_H

#include "button.h"
#include "widget-prop.h"

#include <sigc++/object.h>
#include <gtk--/optionmenu.h>

namespace Guikachu
{
    namespace GUI
    {
	namespace FormEditor
	{
	    class ButtonProperties: public WidgetProperties,
				    public SigC::Object
	    {
		Widgets::Button   *res;
		
		/* Property editor */
		Gtk::Widget       *property_editor;
		
		Gtk::OptionMenu   *frame_combo;

	    public:
		ButtonProperties (Widgets::Button *res);
		~ButtonProperties ();
		Gtk::Widget *get_editor ();

	    private:
		void update ();
		bool update_block;
		
		void frame_menu_cb (Widgets::Button::FrameType frame_type);
	    };
	}
    }
}

#endif /* !GUIKACHU_FORM_EDITOR_BUTTON_PROP_H */
